---
title: <span class="badge object-type-scalar"></span> FemtoFarad
---
# <span class="badge object-type-scalar"></span> FemtoFarad

Energy: Femtofarad (fF)

## Definition

```python
# Energy: Femtofarad (fF)
FemtoFarad: typing.Literal["ffarad"] = "ffarad"
```
